#
# spec file for package suse-hpc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Summary:        SUSE HPC Environment
License:        BSD-3-Clause
Group:          Productivity/Clustering/Computing
Name:           suse-hpc
Version:        0.5.20250102.dbdcd3e
Release:        1.3
Source0:        macros.hpc
Source1:        dlinfo.c
Source2:        hpc_elf.pl
Source3:        hpc_elf.attr
Source4:        hpc_elflib.attr
Source5:        LICENSE
URL:            http://www.suse.com/hpc

%description
Provide rpm macros for building and installing SUSE HPC
packages.

%prep
cp %{S:1} .

%build
gcc -o dlinfo dlinfo.c -ldl

%install
mkdir -p  %{buildroot}%{_rpmconfigdir}/macros.d
install -m 644 %{S:0} %{buildroot}%{_rpmconfigdir}/macros.d
mkdir -p  %{buildroot}%{_rpmconfigdir}/fileattrs
install -m 755 %{S:2} dlinfo %{buildroot}%{_rpmconfigdir}
install -m 644 %{S:3} %{S:4} %{buildroot}%{_rpmconfigdir}/fileattrs
cp %{S:5} .

%if 0%{?sle_version} > 120200 || 0%{?suse_version} > 1320
%define mylicense %license
%else
%define mylicense %doc
%endif

%files
%mylicense LICENSE
%{_rpmconfigdir}/macros.d/macros.hpc
%{_rpmconfigdir}/dlinfo
%{_rpmconfigdir}/hpc_elf.pl
%{_rpmconfigdir}/fileattrs/*

%changelog
* Thu Jan  2 2025 Egbert Eich <eich@suse.com>
- Stop storing mtime in gzip headers to make build reproducible.
  Fixed by Bernhard M. Wiedemann <bwiedemann@suse.de>
* Sat Feb  3 2024 Egbert Eich <eich@suse.com>
- Fix master package README generation 'trick' for rpm <= 4.19.1
  rpm version 4.19.1 started to add quotes around the file name
  when it expands a %%doc statements into a script. This broke
  the 'trick' we've used to generate a README file on-the-fly.
  Here the saving grace was the introduction of the macro %%rpmversion
  with the same version of rpm that can be used to identify
  versions affected by this.
* Thu Oct 26 2023 Egbert Eich <eich@suse.com>
- Previous fix did not work, revert and use %%global instead of
  %%define.
  The %%hpc_cmake and %%hpc_ninja macros wrap the %%cmake and %%ninja macros.
  The wrapper needs to set all standard variables passed to cmake in these
  macros to the hpc values.
  With the mentioned macros this leads to an infinite recursion if using
  %%define. So we use %%global instead.
* Tue Oct 24 2023 Egbert Eich <eich@suse.com>
- Handle %%hpc_localstatedir and %%hpc_sharedstatedir only when
  changed from %%_localstatedir and %%_sharedstatedir to avoid
  infinite recursion.
* Mon May  1 2023 Egbert Eich <eich@suse.com>
- Do not redefine _localstatedir and _sharedstatedir for cmake:
  hpc_localstatedir and hpc_sharedstatedir are already the
  same. This may lead to a endless recursive definition loop.
- Create header magic for module file if none is specified in
  spec file.
* Wed May 25 2022 Egbert Eich <eich@suse.com>
- Add %%hpc_base_dirs macro
  In contrast to %%hpc_dirs which also includes the library directory
  this only provides the HPC base directories.
* Sun Feb  6 2022 Egbert Eich <eich@suse.com>
- Add %%hpc_python_sitelib and %%hpc_python_sitelib_no_singlespec
  to get arch independent module directories for modules.
* Wed Jan  5 2022 Ben Greiner <code@bnavigator.de>
- Update to version 0.5.20211210.07cc46c
  * support python 3.10 version string (#8)
- Update _service to save git date and hash to version
* Sat Oct 23 2021 Egbert Eich <eich@suse.com>
- Cope with the fact that RPM 4.17 no longer has
  __elflib_exclude_path defined.
  Thanks to Dominique Leuenberger <dimstar@opensuse.org> for
  spotting this!
* Mon Mar 15 2021 Egbert Eich <eich@suse.com>
- Add hooks for extra module files and master packages to
  accomodate support for multiple python3 flavors (thanks to
  Ben Greiner).
- Made sure, these macros are backward compatible to Leap 15.
* Mon Jan 18 2021 Egbert Eich <eich@suse.com>
- Expand python_flavor to python executable. Thanks to Ben Greiner.
* Thu Jul 23 2020 Egbert Eich <eich@suse.com>
- Fix %%%%hpc_base during hpc_init to allow for changes to %%%%_prefix.
* Thu May  7 2020 Egbert Eich <eich@suse.com>
- Fix typo in shell script variable.
* Mon Apr 27 2020 Egbert Eich <eich@suse.com>
- Add 'Obsolete:' option to master package. This way, a removed
  master package may be declared obsolte.
- Allow 'Empty' package - without a 'Requires:' to keep master
  package for backward compatibility.
* Wed Feb  6 2019 eich@suse.com
- macros.hpc: Fix default moduleversion link generation and deletion
  * Generation: convert to a posttrans script to make sure the link
    target exists.
  * Deletion: Fix paths and line endings.
  (bsc#1124509)
- macros.hpc: Improve documentation for -L option in %%%%hpc_master macro.
- macros.hpc: Improve master package description and README message.
* Mon Jan  7 2019 eich@suse.com
- Remove redefinition of _sysconfdir in %%%%hpc_cmake:
  Redefining _sysconfdir to %%%%hpc_sysconfdir caused a recursive loop!
* Fri Dec 14 2018 Todd R <toddrme2178@gmail.com>
- Add hpc_docdir macro.
- Add cmake directories macros.
- Use upstream-recommended %%{_rpmconfigdir}/macros.d directory
  for rpm macros.
- Add meson macro.
- Future-proof cmake macro.
* Mon Nov 19 2018 eich@suse.com
- Improve python handling:
  * set python3 as default for Factory
  * allow to specify subdir to HPC pyton path
  * Do not remove executable flag on .so files
* Sun Nov 18 2018 eich@suse.com
- Expand modules handling (bsc#1116458):
  * add %%%%hpc_modules_init to store the list of modules
  * if a modules list is available, use environment during
    dependency generation to exclude objects which will be
    found thru environment modules.
  * bump package version.
* Fri Oct 26 2018 eich@suse.com
- Add %%%%hpc_cmake which wraps %%%%cmake from marcos.cmake.
* Thu Oct 25 2018 eich@suse.com
- macros: fix unexpanded macro in description of master package.
* Sun Aug 19 2018 eich@suse.com
- macros: %%hpc_master_package: properly escape '\'
* Sun Aug 19 2018 eich@suse.com
- macros:
  * Fix line endings
  * Replace %%%%compiler_family by %%%%hpc_compiler_family
* Tue Jun 19 2018 eich@suse.com
- Handle license file using %%license where applicable.
* Mon Jun 18 2018 eich@suse.com
- Improve description and README in master packages
  Explain the purpose of the package and explicitly specify the dependency
  in the package description and generated README.
* Sat Jun 16 2018 eich@suse.com
-  Fix master package summary and description
-  Add support for different name than %%name
* Mon Mar 12 2018 eich@suse.com
- Append a newline to the shebang line prepended by the
  %%hpc_shebang_prepend_list macro (boo#1084951).
* Sun Feb 25 2018 eich@suse.com
- Add functions to:
  * sanitize the shebang path in scripts,
  * move python code to the local site arch directory removing
    any leading shebang line and execute bits
  * Add the appropriate shebang line to a script and set the
    execution bit.
  * validate Python 3 code (bsc#1082209).
* Fri Feb  9 2018 eich@suse.com
- Fix summary in module files (bnc#1080259).
* Tue Jan 30 2018 eich@suse.com
- For tool don't distinguish minor versions:
  %%hpc_cf_dep_version represents what we distinguish
  which determines the granularity in compiler selection.
* Mon Nov 20 2017 eich@suse.com
- Add lua-lmod to the HPC base Requires
- Fix %%name in %%hpc_python_master_package
  Not only %%pname but also %%name needs to have python replaced
  by %%python_flavor.
- Add macro to santize %%pname for environment variables
  This marco up-cases the name and replaces '-' by '_'.
* Thu Oct 19 2017 eich@suse.com
- Fix master package macro to handle sub-packages with a
  different basename correctly.
* Fri Oct  6 2017 nmoreychaisemartin@suse.com
- Add _service to fetch github files
* Thu Oct  5 2017 eich@suse.com
- Make source files downloadable from git.
* Wed Oct  4 2017 eich@suse.com
- Add more documentation.
- Fix LICENSE and copyright statement in LICENSE.
* Thu Sep 21 2017 nmoreychaisemartin@suse.com
- Add %%{?hpc_ext} to install path to allow multiple flavor installs
* Wed Sep 13 2017 eich@suse.com
- Add a dependency generator wrapper for binaries and libraries
  to avoid adding standard dependencies for HPC libraries.
* Tue Sep 12 2017 eich@suse.com
- Removed unneeded BuildRequires:
* Wed May  3 2017 eich@suse.com
- Initial version (FATE#320596).
